@@ -40,6 +40,21 @@ def runserver(host, port):
     app.run(host=host, port=port, debug=True)
 
 
+@cmd.command()
+def sync_customers():
+    """Udpate customers from CRM"""
+    LOGS.logger.info("Sync customers from CRM -- START")
+    products = Product.all()
+    for product in products:
+        customers = core.get_customers_crm(product)
+        for customer in customers:
+            name = customer['ident'].lower()
+            product_name = customer['produit_nom']
+            refnum = customer['refnum_primaire']
+            core.sync_customer(name, product_name, refnum)
+    LOGS.logger.info("Sync customers from CRM -- END")
+
+
 @cmd.command()
 @click.option('--last-date', default=False)
 @click.option('--product-ese', is_flag=True, default=False)
@@ -54,7 +69,12 @@ def sync(last_date, product_ese):
     if not product_ese:
         products = Product.all()
         for product in products:
-            product.update_customers()
+            customers = core.get_customers_crm(product)
+            for customer in customers:
+                name = customer['ident'].lower()
+                product_name = customer['produit_nom']
+                refnum = customer['refnum_primaire']
+                core.sync_customer(name, product_name, refnum)
             f = partial(core.update_customer_cdr, last_date)
             with Pool(processes=2) as pool:
                 pool.map(f, product.customers)
@@ -189,6 +209,7 @@ def reconciled(product):
         customers_aiguiller = [
             customer['name'].lower()
             for customer in fuped_aiguiller
+            if customer['name']  # prevents 'None' instances exceptions
         ]
         customers_si = core.get_customers_si()
         print("customers in database: {}".format(len(customers_si)))
