@@ -343,7 +343,6 @@ def update_consommation(product, policy, customer, date, id, total):
     )
 
 
-
 def get_consommation_sum():
     sql = (
         "SELECT SUM(octets_in+octets_out)"
@@ -388,13 +387,37 @@ def send_error_report(operation, error):
         "Error: {}"
         .format("fup-services", APIGW, operation, error)
     )
-    destinations = ["dev@si.blueline.mg", "sysadmin@si.blueline.mg"]
+    sender = "api-gateway@si.blueline.mg"
+    # destinations = ["dev@si.blueline.mg", "sysadmin@si.blueline.mg"]
+    destinations = ["yona.rasolonjatovo@staff.blueline.mg",]
+    content = MIMEText(message, 'plain', 'utf-8')
 
-    send_email(
-        destinations=destinations,
-        subject="fup-services process error",
-        message=message
-    )
+    msg = MIMEMultipart()
+    msg['Subject'] = "fup-services process error"
+    msg['From'] = sender
+    msg['To'] = ', '.join(destinations)
+    msg['Date'] = formatdate(localtime=True)
+    msg.attach(content)
+    smtp = smtplib.SMTP('localhost')
+    smtp.sendmail(sender, destinations, msg.as_string())
+    smtp.quit()
+
+    LOGS.logger.info(
+        "Email: '{}' sent to {}".format(msg['Subject'], destinations))
+    smtp.quit()
+    # message = (
+    #     "Service: {} [{}]\n\n"
+    #     "Affected operation: {}\n\n"
+    #     "Error: {}"
+    #     .format("fup-services", APIGW, operation, error)
+    # )
+    # destinations = ["dev@si.blueline.mg", "sysadmin@si.blueline.mg"]
+    #
+    # send_email(
+    #     destinations=destinations,
+    #     subject="fup-services process error",
+    #     message=message
+    # )
 
 
 def send_email(destinations, subject, message, attachment=None):
